=============
Django Robots
=============

This is a basic Django application to manage robots.txt files following the
`robots exclusion protocol`_, complementing the Django_ `Sitemap contrib app`_.

For installation instructions, see the file "INSTALL.txt" in this
directory; for instructions on how to use this application, and on
what it provides, see the file "overview.txt" in the "docs/"
directory.

.. _robots exclusion protocol: http://www.robotstxt.org/robotstxt.html
.. _Django: http://www.djangoproject.com/
.. _Sitemap contrib app: http://www.djangoproject.com/documentation/sitemaps/
